# {{NAME}}

Data Feed for the [Energy Dashboard](https://github.com/energy-analytics-project/energy-dashboard).

See `./manifest.json` for feed metadata such as maintainer, description, etc.

## License

See `./LICENSE`.
